@@ -18,6 +18,16 @@ use Path::Class qw(file dir);
 use DBIx::Class::Schema::Loader;
 use DBIx::Class::Schema::Diff;
 
+BEGIN {
+  require DBIx::Class::Optional::Dependencies;
+  unless ( DBIx::Class::Optional::Dependencies->req_ok_for('deploy') ) {
+    die(
+      "Required DBIx::Class 'deploy' dependencies missing: "
+     . ( values %{ DBIx::Class::Optional::Dependencies->req_errorlist_for('deploy') } )[0] 
+    );
+  }
+}
+
 # --------------------
 # User can set their own sqlite file/path by doing this in main app class:
 #
